You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@ant.apache.org by bo...@apache.org on 2017/01/12 16:30:16 UTC

ant git commit: Fixed a typo (instanciated -> instantiated)

Repository: ant
Updated Branches:
  refs/heads/1.9.x 296086084 -> 0c38fb606


Fixed a typo (instanciated -> instantiated)


Project: http://git-wip-us.apache.org/repos/asf/ant/repo
Commit: http://git-wip-us.apache.org/repos/asf/ant/commit/0c38fb60
Tree: http://git-wip-us.apache.org/repos/asf/ant/tree/0c38fb60
Diff: http://git-wip-us.apache.org/repos/asf/ant/diff/0c38fb60

Branch: refs/heads/1.9.x
Commit: 0c38fb606fd48312925a95814b37f8f0fa277127
Parents: 2960860
Author: Emmanuel Bourg <eb...@apache.org>
Authored: Thu Jan 12 09:34:20 2017 +0100
Committer: Stefan Bodewig <bo...@apache.org>
Committed: Thu Jan 12 17:29:53 2017 +0100

----------------------------------------------------------------------
 manual/projecthelper.html                                    | 6 +++---
 src/main/org/apache/tools/ant/ArgumentProcessorRegistry.java | 4 ++--
 src/main/org/apache/tools/ant/ProjectHelperRepository.java   | 2 +-
 3 files changed, 6 insertions(+), 6 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ant/blob/0c38fb60/manual/projecthelper.html
----------------------------------------------------------------------
diff --git a/manual/projecthelper.html b/manual/projecthelper.html
index fa07aea..2e43f79 100644
--- a/manual/projecthelper.html
+++ b/manual/projecthelper.html
@@ -70,13 +70,13 @@ in the same order they've been found in an internal 'repository':
         service declarations in the META-INF: it searches in the classpath for a
         file <code>META-INF/services/org.apache.tools.ant.ProjectHelper</code>.
         This file will just contain the fully qualified name of the
-        implementation of <code>ProjectHelper</code> to instanciate;</li>
+        implementation of <code>ProjectHelper</code> to instantiate;</li>
     <li>it will also search with the system class loader for
         <code>ProjectHelper</code> service declarations in the META-INF;</li>
     <li>last but not least it will add its default <code>ProjectHelper</code>
         that can parse classical build.xml files.</li>
 </ul>
-In case of an error while trying to instanciate a <code>ProjectHelper</code>, Ant
+In case of an error while trying to instantiate a <code>ProjectHelper</code>, Ant
 will log an error but won't stop.  If you want further debugging
 info about the <code>ProjectHelper</code> internal 'repository', use the <b>system</b>
 property <code>ant.project-helper-repo.debug</code> and set it to
@@ -104,7 +104,7 @@ The class <code>org.apache.tools.ant.ProjectHelper</code> is the API expected to
 be implemented. So write your own <code>ProjectHelper</code> by extending that
 abstract class. You are then expected to implement at least the function
 <code>parse(Project project, Object source)</code>. Note also that your
-implementation will be instanciated by Ant, and it is expecting a default
+implementation will be instantiated by Ant, and it is expecting a default
 constructor with no arguments.
 </p>
 

http://git-wip-us.apache.org/repos/asf/ant/blob/0c38fb60/src/main/org/apache/tools/ant/ArgumentProcessorRegistry.java
----------------------------------------------------------------------
diff --git a/src/main/org/apache/tools/ant/ProjectHelperRepository.java b/src/main/org/apache/tools/ant/ProjectHelperRepository.java
index 7fe92c4..e370a54 100644
--- a/src/main/org/apache/tools/ant/ProjectHelperRepository.java
+++ b/src/main/org/apache/tools/ant/ProjectHelperRepository.java
@@ -46,7 +46,7 @@ public class ProjectHelperRepository {
         "ant.project-helper-repo.debug";
 
     // The message log level is not accessible here because everything
-    // is instanciated statically
+    // is instantiated statically
     private static final boolean DEBUG =
         "true".equals(System.getProperty(DEBUG_PROJECT_HELPER_REPOSITORY));
diff --git a/src/main/org/apache/tools/ant/ArgumentProcessorRegistry.java b/src/main/org/apache/tools/ant/ArgumentProcessorRegistry.java
index 1ede565..ed3331f 100644
--- a/src/main/org/apache/tools/ant/ArgumentProcessorRegistry.java
+++ b/src/main/org/apache/tools/ant/ArgumentProcessorRegistry.java
@@ -48,7 +48,7 @@ public class ArgumentProcessorRegistry {
     private static final String DEBUG_ARGUMENT_PROCESSOR_REPOSITORY = "ant.argument-processor-repo.debug";
 
     // The message log level is not accessible here because everything
     // is instanciated statically
     private static final boolean DEBUG = "true".equals(System.getProperty(DEBUG_ARGUMENT_PROCESSOR_REPOSITORY));
 
     private static final String SERVICE_ID = "META-INF/services/org.apache.tools.ant.ArgumentProcessor";
@@ -128,7 +128,7 @@ public class ArgumentProcessorRegistry {
         } catch (Exception e) {
             throw new BuildException("The argument processor class"
                     + processorClass.getClass().getName()
-                    + " could not be instanciated with a default constructor",
+                    + " could not be instantiated with a default constructor",
                     e);
         }
         return processor;

http://git-wip-us.apache.org/repos/asf/ant/blob/0c38fb60/src/main/org/apache/tools/ant/ProjectHelperRepository.java
----------------------------------------------------------------------
@@ -48,7 +48,7 @@ public class ArgumentProcessorRegistry {
 
     // The message log level is not accessible here because everything
-    // is instanciated statically
+    // is instantiated statically
     private static final boolean DEBUG = "true".equals(System.getProperty(DEBUG_ARGUMENT_PROCESSOR_REPOSITORY));
 